Documentation
¶
Index ¶
- Constants
- type SharedContext
- func (shared SharedContext) Close()
- func (SharedContext) CreateCache(ctx context.Context, client momento.CacheClient, cacheName string) (responses.CreateCacheResponse, error)
- func (SharedContext) DeleteCache(ctx context.Context, client momento.CacheClient, cacheName string) (responses.DeleteCacheResponse, error)
Constants ¶
const AuthTokenEnvVariable string = "TEST_AUTH_TOKEN"
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type SharedContext ¶
type SharedContext struct {
UseRedis bool
// Client the wrapper Client implements all methods of the Cmdable interface supporting all Redis commands.
// Note that this doesn't include commands exposed by ClusterClient, which isn't applicable if you're
// using Momento as we provide resource-level isolation and have no notion of a cluster exposed to our customers.
// This type declaration here serves as a validation and compile-time errors will occur if we do not implement
// any particular API exposed the go-redis Client
}
func NewSharedContext ¶
func NewSharedContext() SharedContext
func (SharedContext) Close ¶ added in v1.1.0
func (shared SharedContext) Close()
func (SharedContext) CreateCache ¶
func (SharedContext) CreateCache(ctx context.Context, client momento.CacheClient, cacheName string) (responses.CreateCacheResponse, error)
func (SharedContext) DeleteCache ¶
func (SharedContext) DeleteCache(ctx context.Context, client momento.CacheClient, cacheName string) (responses.DeleteCacheResponse, error)
Click to show internal directories.
Click to hide internal directories.